==> core_plugin-0.1.5.tar.gz: lib/checkout/checkout_model.dart <==
class CheckoutDataModel {
  CheckoutModel data;

  CheckoutDataModel({this.data});

  factory CheckoutDataModel.fromJson(Map<String, dynamic> parsedJson) {
    return CheckoutDataModel(data: CheckoutModel.fromJson(parsedJson['data']));
  }
}

class CheckoutModel {
  CustomerInfo customerData;
  List<ShopInfo> shopInfos;

  CheckoutModel({this.customerData, this.shopInfos});

  factory CheckoutModel.fromJson(Map<String, dynamic> parsedJson) {
    List<ShopInfo> shopInfoList = new List();
    if (parsedJson.containsKey('shop_info')) {
      var list = parsedJson['shop_info'] as List;
      shopInfoList = list.map((i) => ShopInfo.fromJson(i)).toList();
    }

    return CheckoutModel(
        customerData: CustomerInfo.fromJson(
            parsedJson['customer_data'] ?? new CustomerData()),
        shopInfos: shopInfoList);
  }
}

class CustomerInfo {
  final CustomerData customerData;
  BadBuyerInfo badBuyerInfo;
  List<CustomerAddress> customerAddress;

  CustomerInfo({this.customerData, this.badBuyerInfo, this.customerAddress});

  factory CustomerInfo.fromJson(Map<String, dynamic> parsedJson) {
    List<CustomerAddress> customerAddressList = new List();
    if (parsedJson.containsKey('customer_address')) {
      var list = parsedJson['customer_address'] as List;
      customerAddressList =
          list.map((i) => CustomerAddress.fromJson(i)).toList();
    }

    return CustomerInfo(
        badBuyerInfo: BadBuyerInfo.fromJson(
            parsedJson['bad_buyer_info'] ?? new BadBuyerInfo()),
        customerData: CustomerData.fromJson(
            parsedJson['customer_data'] ?? new CustomerData()),
        customerAddress: customerAddressList);
  }
}

class CustomerData {
  final String customerId;
  final String fptId;
  final String telephone;
  final String firstName;
  final String lastName;
  final String email;
  final String isOtpPhone;

  CustomerData(
      {this.customerId,
      this.fptId,
      this.telephone,
      this.firstName,
      this.lastName,
      this.email,
      this.isOtpPhone});

  factory CustomerData.fromJson(Map<String, dynamic> json) {
    return CustomerData(
        customerId: json['customer_id'] ?? '',
        fptId: json['fpt_id'] ?? '',
        telephone: json['telephone'] ?? '',
        firstName: json['firstname'] ?? '',
        lastName: json['lastname'] ?? '',
        email: json['email'] ?? '',
        isOtpPhone: json['is_otp_phone'] ?? '');
  }
}

class BadBuyerInfo {
  final bool shopBlock;

  final bool blockCod;

  final bool otpCod;

  BadBuyerInfo(
      {this.shopBlock = false, this.blockCod = false, this.otpCod = false});

  factory BadBuyerInfo.fromJson(Map<String, dynamic> json) {
    return BadBuyerInfo(
        blockCod: json['block_cod'] ?? false,
        otpCod: json['otp_cod'] ?? false,
        shopBlock: json['shop_block'] ?? false);
  }
}

class CustomerAddress {
  final String customerId;
  final String fptId;
  final String createdAt;
  final String addressId;
  final String firstName;
  final String lastName;
  final String city;
  final String cityId;
  final String district;
  final String districtId;
  final String ward;
  final String wardId;
  final String street;
  final String telephone;
  final String email;
  final String latitude;
  final String longitude;
  final String fullAddress;
  final bool isDefaultShipping;

  CustomerAddress(
      {this.customerId,
      this.fptId,
      this.createdAt,
      this.addressId,
      this.firstName,
      this.lastName,
      this.city,
      this.cityId,
      this.district,
      this.districtId,
      this.ward,
      this.wardId,
      this.street,
      this.telephone,
      this.email,
      this.latitude,
      this.longitude,
      this.fullAddress,
      this.isDefaultShipping});

  factory CustomerAddress.fromJson(Map<String, dynamic> json) {
    // : customerId = json['customer_id'].toString() ?? '',
    //   fptId = json['fpt_id'].toString() ?? '',
    //   createdAt = json['created_at'].toString() ?? '',
    //   addressId = json['address_id'].toString() ?? '',
    //   firstName = json['firstname'].toString() ?? '',
    //   lastName = json['lastname'].toString() ?? '',
    //   city = json['city'].toString() ?? '',
    //   cityId = json['city_id'].toString() ?? '',
    //   district = json['district'].toString() ?? '',
    //   districtId = json['district_id'].toString() ?? '',
    //   ward = json['ward'].toString() ?? '',
    //   wardId = json['ward_id'].toString() ?? '',
    //   street = json['street'].toString() ?? '',
    //   telephone = json['telephone'].toString() ?? '',
    //   email = json['email'].toString() ?? '',
    //   latitude = json['latitude'].toString() ?? '',
    //   longitude = json['longitude'].toString() ?? '',
    //   fullAddress = json['full_address'].toString() ?? '',
    //   isDefaultShipping = json['is_default_shipping'] ?? '';

    return CustomerAddress(
        customerId: json['customer_id'].toString() ?? '',
        fptId: json['fpt_id'].toString() ?? '',
        createdAt: json['created_at'].toString() ?? '',
        addressId: json['address_id'].toString() ?? '',
        firstName: json['firstname'].toString() ?? '',
        lastName: json['lastname'].toString() ?? '',
        city: json['city'].toString() ?? '',
        cityId: json['city_id'].toString() ?? '',
        district: json['district'].toString() ?? '',
        districtId: json['district_id'].toString() ?? '',
        ward: json['ward'].toString() ?? '',
        wardId: json['ward_id'].toString() ?? '',
        street: json['street'].toString() ?? '',
        telephone: json['telephone'].toString() ?? '',
        email: json['email'].toString() ?? '',
        latitude: json['latitude'].toString() ?? '',
        longitude: json['longitude'].toString() ?? '',
        fullAddress: json['full_address'].toString() ?? '',
        isDefaultShipping: json['is_default_shipping'] ?? '');
  }
}

class ShopInfo {
  final String shopId;
  final String externalId;
  final String name;
  final String shopType;
  final bool canUseSuperFastDelivery;

  ShopInfo(
      {this.shopId,
      this.externalId,
      this.name,
      this.shopType,
      this.canUseSuperFastDelivery});

  factory ShopInfo.fromJson(Map<String, dynamic> json) {
    return ShopInfo(
        shopId: json['shop_id'],
        externalId: json['external_id'],
        name: json['name'],
        shopType: json['shop_type'],
        canUseSuperFastDelivery: json['can_use_super_fast_delivery']);
  }
}

==> core_plugin-0.1.6.tar.gz: lib/checkout/checkout_model.dart <==
class CheckoutDataModel {
  CheckoutModel data;

  CheckoutDataModel({this.data});

  factory CheckoutDataModel.fromJson(Map<String, dynamic> parsedJson) {
    return CheckoutDataModel(data: CheckoutModel.fromJson(parsedJson['data']));
  }
}

class CheckoutModel {
  CustomerInfo customerData;
  List<ShopInfo> shopInfos;

  CheckoutModel({this.customerData, this.shopInfos});

  factory CheckoutModel.fromJson(Map<String, dynamic> parsedJson) {
    List<ShopInfo> shopInfoList = new List();
    if (parsedJson.containsKey('shop_info')) {
      var list = parsedJson['shop_info'] as List;
      shopInfoList = list.map((i) => ShopInfo.fromJson(i)).toList();
    }

    return CheckoutModel(
        customerData: CustomerInfo.fromJson(
            parsedJson['customer_data'] ?? new CustomerData()),
        shopInfos: shopInfoList);
  }
}

class CustomerInfo {
  final CustomerData customerData;
  BadBuyerInfo badBuyerInfo;
  List<CustomerAddress> customerAddress;

  CustomerInfo({this.customerData, this.badBuyerInfo, this.customerAddress});

  factory CustomerInfo.fromJson(Map<String, dynamic> parsedJson) {
    List<CustomerAddress> customerAddressList = new List();
    if (parsedJson.containsKey('customer_address')) {
      var list = parsedJson['customer_address'] as List;
      customerAddressList =
          list.map((i) => CustomerAddress.fromJson(i)).toList();
    }

    return CustomerInfo(
        badBuyerInfo: BadBuyerInfo.fromJson(
            parsedJson['bad_buyer_info'] ?? new BadBuyerInfo()),
        customerData: CustomerData.fromJson(
            parsedJson['customer_data'] ?? new CustomerData()),
        customerAddress: customerAddressList);
  }
}

class CustomerData {
  final String customerId;
  final String fptId;
  final String telephone;
  final String firstName;
  final String lastName;
  final String email;
  final String isOtpPhone;

  CustomerData(
      {this.customerId,
      this.fptId,
      this.telephone,
      this.firstName,
      this.lastName,
      this.email,
      this.isOtpPhone});

  factory CustomerData.fromJson(Map<String, dynamic> json) {
    return CustomerData(
        customerId: json['customer_id'] ?? '',
        fptId: json['fpt_id'] ?? '',
        telephone: json['telephone'] ?? '',
        firstName: json['firstname'] ?? '',
        lastName: json['lastname'] ?? '',
        email: json['email'] ?? '',
        isOtpPhone: json['is_otp_phone'] ?? '');
  }
}

class BadBuyerInfo {
  final bool shopBlock;

  final bool blockCod;

  final bool otpCod;

  BadBuyerInfo(
      {this.shopBlock = false, this.blockCod = false, this.otpCod = false});

  factory BadBuyerInfo.fromJson(Map<String, dynamic> json) {
    return BadBuyerInfo(
        blockCod: json['block_cod'] ?? false,
        otpCod: json['otp_cod'] ?? false,
        shopBlock: json['shop_block'] ?? false);
  }
}

class CustomerAddress {
  final String customerId;
  final String fptId;
  final String createdAt;
  final String addressId;
  final String firstName;
  final String lastName;
  final String city;
  final String cityId;
  final String district;
  final String districtId;
  final String ward;
  final String wardId;
  final String street;
  final String telephone;
  final String email;
  final String latitude;
  final String longitude;
  final String fullAddress;
  final bool isDefaultShipping;

  CustomerAddress(
      {this.customerId,
      this.fptId,
      this.createdAt,
      this.addressId,
      this.firstName,
      this.lastName,
      this.city,
      this.cityId,
      this.district,
      this.districtId,
      this.ward,
      this.wardId,
      this.street,
      this.telephone,
      this.email,
      this.latitude,
      this.longitude,
      this.fullAddress,
      this.isDefaultShipping});

  factory CustomerAddress.fromJson(Map<String, dynamic> json) {

    return CustomerAddress(
        customerId: json['customer_id'].toString() ?? '',
        fptId: json['fpt_id'].toString() ?? '',
        createdAt: json['created_at'].toString() ?? '',
        addressId: json['address_id'].toString() ?? '',
        firstName: json['firstname'].toString() ?? '',
        lastName: json['lastname'].toString() ?? '',
        city: json['city'].toString() ?? '',
        cityId: json['city_id'].toString() ?? '',
        district: json['district'].toString() ?? '',
        districtId: json['district_id'].toString() ?? '',
        ward: json['ward'].toString() ?? '',
        wardId: json['ward_id'].toString() ?? '',
        street: json['street'].toString() ?? '',
        telephone: json['telephone'].toString() ?? '',
        email: json['email'].toString() ?? '',
        latitude: json['latitude'].toString() ?? '',
        longitude: json['longitude'].toString() ?? '',
        fullAddress: json['full_address'].toString() ?? '',
        isDefaultShipping: json['is_default_shipping'] ?? false);
  }
}

class ShopInfo {
  final String shopId;
  final String externalId;
  final String name;
  final String shopType;
  final bool canUseSuperFastDelivery;

  ShopInfo(
      {this.shopId,
      this.externalId,
      this.name,
      this.shopType,
      this.canUseSuperFastDelivery});

  factory ShopInfo.fromJson(Map<String, dynamic> json) {
    return ShopInfo(
        shopId: json['shop_id'].toString() ?? '',
        externalId: json['external_id'].toString() ?? '',
        name: json['name'].toString() ?? '',
        shopType: json['shop_type'].toString() ?? '',
        canUseSuperFastDelivery: json['can_use_super_fast_delivery'] ?? false);
  }
}
